# inm-rspace

Python tools for interaction with the Rspace Electronic Lab Notebook. Developed at INM - Leibniz Institute for New Materials in Saarbrücken, Germany.


## Installation

Currently only available on `test.pypi.org`. 
Soon moving to `pypi.org`, which will facilitate installation through:

`pip install inm-rspace`

## Examples

Coming soon...


## Documentation

The full API documentation is available [here](https://sintharic.github.io/inm-rspace/).